.. _versionah-label:

:mod:`versionah`
================

:mod:`versionah` is a simple tool to help you, or more specifically *me*, easily
maintain version information for a project.  Its entire aim is to make the act
of displaying or bumping a project's version number a thoughtless task.

All repetitive tasks should be easily automated, and :mod:`versionah` is just a
little step in the right direction!

It is written in Python_, and requires v2.6 or later.  :mod:`versionah` is
released under the `GPL v3`_

:Git repository:  https://github.com/JNRowe/versionah/
:Issue tracker:  https://github.com/JNRowe/versionah/issues/
:Contributors:  https://github.com/JNRowe/versionah/contributors/

Contents
--------

.. toctree::
   :maxdepth: 2

   background
   usage
   getting_started
   templates
   versionah manpage <versionah.1>
   faq
   alternatives
   api/index
   release
   appendix

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _Python: http://www.python.org/
.. _GPL v3: http://www.gnu.org/licenses/
